#
# Cookbook Name:: bjn_franz
# Recipe:: default
#
# Copyright (C) 2014 Blue Jeans Network
#

franz = materialize node['franz']

reify_packages franz['packages']

# Install all the service prerequisites
include_recipe 'bjn_franz::prep'

gem_notifications = franz['config'].keys.map do |name|
  [ :restart, "service[franz-#{name}]" ]
end

reify :gem_package, franz['gem'], gem_notifications, :upgrade


# Add agent configurations and services
franz['config'].each do |name, config|
  service_name = "franz-#{name}"
  config_path = "#{franz['directories']['config']['path']}/#{service_name}.json"

  file config_path do
    content json_config(config)
    owner franz['user']['name']
    group franz['group']['name']
    notifies :restart, "service[#{service_name}]", :delayed
  end

  template "/etc/init/#{service_name}.conf" do
    source 'franz.conf.erb'
    owner 'root'
    group 'root'
    mode '0644'
    variables \
      service_name: service_name,
      config_path: config_path,
      log_path: "#{franz['directories']['logs']['path']}/#{service_name}.log",
      opts: shell_opts(franz['opts']),
      franz: franz
    notifies :restart, "service[#{service_name}]", :delayed
  end

  service service_name do
    provider Chef::Provider::Service::Upstart
    supports restart: true, reload: false, status: true
    action [ :enable, :start ]
  end
end